@@ -1,6 +1,7 @@
 from . import mixins
-from .HowFairIsChecker import HowFairIsChecker
 from .__version__ import __version__
+from .HowFairIsChecker import HowFairIsChecker
+from .Platform import Platform
 
 
 __author__ = "https://github.com/jspaaks"
@@ -8,6 +9,7 @@ __email__ = 'j.spaaks@esciencecenter.nl'
 
 __all__ = [
     "HowFairIsChecker",
+    "Platform",
     "mixins",
     "__version__"
 ]
